VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package rstack

Package {rstack}


Title: Stack Data Type as an 'R6' Class
Version: 1.0.1
Author: Gábor Csárdi
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Description: An extremely simple stack data type, implemented with 'R6' classes. The size of the stack increases as needed, and the amortized time complexity is O(1). The stack may contain arbitrary objects.
License: MIT + file LICENSE
URL: https://github.com/gaborcsardi/rstack#readme
BugReports: https://github.com/gaborcsardi/rstack/issues
RoxygenNote: 7.2.3
Imports: R6
Suggests: covr, testthat
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2023-08-30 16:31:23 UTC; gaborcsardi
Repository: CRAN
Date/Publication: 2023-08-30 17:20:02 UTC

A stack data type, implemented as an R6 class

Description

Methods:

Examples

S <- stack$new()
S$push(1L)
S$peek()
S$pop()
S$size()

S$push(NULL)
S$push(iris)
colnames(S$peek())

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.